:orphan:

{{ fullname }}
{{ underline }}

.. currentmodule:: {{ module }}

Class : {{ objname }}
------------------------------------------

.. autoclass:: {{ objname }}
   :no-members:

.. autoclass:: {{ objname }}InputSpec

.. autoclass:: {{ objname }}OutputSpec


